@@ -124,10 +124,6 @@ YAZ_EXPORT void nmem_destroy(NMEM n);
  */
 YAZ_EXPORT void *nmem_malloc(NMEM n, int size);
 
-YAZ_EXPORT int yaz_errno(void);
-YAZ_EXPORT void yaz_set_errno (int v);
-YAZ_EXPORT void yaz_strerror(char *buf, int max);
-
 YAZ_END_CDECL
 
 #endif
