@@ -1,29 +1,28 @@
-/*
- * Copyright (C) 1995-2005, Index Data ApS
+/* This file is part of the YAZ toolkit.
+ * Copyright (C) 1995-2009 Index Data.
+ * All rights reserved.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * Permission to use, copy, modify, distribute, and sell this software and
- * its documentation, in whole or in part, for any purpose, is hereby granted,
- * provided that:
+ *     * Redistributions of source code must retain the above copyright
+ *       notice, this list of conditions and the following disclaimer.
+ *     * Redistributions in binary form must reproduce the above copyright
+ *       notice, this list of conditions and the following disclaimer in the
+ *       documentation and/or other materials provided with the distribution.
+ *     * Neither the name of Index Data nor the names of its contributors
+ *       may be used to endorse or promote products derived from this
+ *       software without specific prior written permission.
  *
- * 1. This copyright and permission notice appear in all copies of the
- * software and its documentation. Notices of copyright or attribution
- * which appear at the beginning of any file must remain unchanged.
- *
- * 2. The name of Index Data or the individual authors may not be used to
- * endorse or promote products derived from this software without specific
- * prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY OF ANY KIND,
- * EXPRESS, IMPLIED, OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY
- * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
- * IN NO EVENT SHALL INDEX DATA BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
- * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES
- * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR
- * NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF
- * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE
- * OF THIS SOFTWARE.
- *
- * $Id: odr.h,v 1.22 2006/02/19 18:33:08 adam Exp $
+ * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
+ * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
+ * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 /**
@@ -40,6 +39,9 @@
 #include <yaz/yconfig.h>
 #include <yaz/nmem.h>
 
+/* for definition of Odr_oid */
+#include <yaz/oid_util.h>
+
 YAZ_BEGIN_CDECL
 
 #ifndef bool_t
@@ -109,41 +111,31 @@ typedef struct odr_bitmask
     int top;
 } Odr_bitmask;
 
-typedef int Odr_oid;   /* terminate by -1 */
-
 #define ODR_S_SET     0
 #define ODR_S_CUR     1
 #define ODR_S_END     2
 
-typedef struct odr
+typedef struct odr *ODR;
+
+/** ODR handle and the public structs */
+struct odr
 {
     int direction;       /* the direction of this stream */
 
-    int error;           /* current error state (0==OK) */
+    int error;            /* current error state (0==OK) */
 
-    int can_grow;         /* are we allowed to reallocate */
     unsigned char *buf;            /* memory handle */
+    int top;              /* top of buffer (max pos when encoding) */
     int size;             /* current buffer size (encoding+decoding) */
 
     int pos;              /* current position (encoding) */
-    int top;              /* top of buffer (max pos when encoding) */
 
     const unsigned char *bp; /* position in buffer (decoding) */
 
-    int t_class;         /* implicit tagging (-1==default tag) */
-    int t_tag;
-
-    int enable_bias;     /* force choice enable flag */
-    int choice_bias;     /* force choice */
-    int lenlen;          /* force length-of-lenght (odr_setlen()) */
-
-    FILE *print;         /* output file handler for direction print */
-    int indent;          /* current indent level for printing */
-
     NMEM mem;            /* memory handle for decoding (primarily) */
 
     struct Odr_private *op;
-} *ODR;
+};
 
 typedef int (*Odr_fun)(ODR, char **, int, const char *);
 
@@ -191,6 +183,7 @@ YAZ_EXPORT char *odr_getbuf(ODR o, int *len, int *size);
 YAZ_EXPORT void *odr_malloc(ODR o, int size);
 YAZ_EXPORT char *odr_strdup(ODR o, const char *str);
 YAZ_EXPORT char *odr_strdupn(ODR o, const char *str, size_t n);
+YAZ_EXPORT char *odr_strdup_null(ODR o, const char *str);
 YAZ_EXPORT int *odr_intdup(ODR o, int v);
 YAZ_EXPORT Odr_oct *odr_create_Odr_oct(ODR o, const unsigned char *buf,
                                        int sz);
@@ -226,7 +219,6 @@ YAZ_EXPORT Odr_null *odr_nullval(void);
 #define odr_offset(o) ((o)->bp - (o)->buf)
 #define odr_ok(o) (!(o)->error)
 #define odr_getmem(o) ((o)->mem)
-#define odr_setmem(o, v) ((o)->mem = (v))
 
 #define ODR_MAXNAME 256
 
@@ -272,12 +264,20 @@ YAZ_EXPORT int odr_sequence_of(ODR o, Odr_fun type, void *p, int *num,
 YAZ_EXPORT int odr_set_of(ODR o, Odr_fun type, void *p, int *num,
                           const char *name);
 YAZ_EXPORT int odr_any(ODR o, Odr_any **p, int opt, const char *name);
+
 YAZ_EXPORT int ber_any(ODR o, Odr_any **p);
+/** \brief determine whether a buffer is a complete BER buffer
+    \param buf BER buffer
+    \param len length of buffer
+    \retval 0 package is incomplete
+    \retval >0 package is complete and length is return value
+*/
 YAZ_EXPORT int completeBER(const unsigned char *buf, int len);
+
 YAZ_EXPORT void odr_begin(ODR o);
 YAZ_EXPORT void odr_end(ODR o);
-YAZ_EXPORT Odr_oid *odr_oiddup(ODR odr, Odr_oid *o);
-YAZ_EXPORT Odr_oid *odr_oiddup_nmem(NMEM nmem, Odr_oid *o);
+YAZ_EXPORT Odr_oid *odr_oiddup(ODR odr, const Odr_oid *o);
+YAZ_EXPORT Odr_oid *odr_oiddup_nmem(NMEM nmem, const Odr_oid *o);
 YAZ_EXPORT int odr_grow_block(ODR b, int min_bytes);
 YAZ_EXPORT int odr_write(ODR o, unsigned char *buf, int bytes);
 YAZ_EXPORT int odr_seek(ODR o, int whence, int offset);
@@ -343,6 +343,7 @@ YAZ_END_CDECL
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
