@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2008 Index Data
+ * Copyright (C) 1995-2009 Index Data
  * See the file LICENSE for details.
  */
 
@@ -23,7 +23,8 @@
 
 #ifdef WIN32
 #include <winsock.h>
-#else
+#endif
+#if HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
 
@@ -111,6 +112,7 @@ int ber_decinteger(const unsigned char *buf, int *val, int max)
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
