@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2008 Index Data
+ * Copyright (C) 1995-2009 Index Data
  * See the file LICENSE for details.
  */
 
@@ -19,15 +19,12 @@
 #include <unistd.h>
 #endif
 #include <stdlib.h>
-#include <signal.h>
 #if HAVE_SYS_WAIT_H
 #include <sys/wait.h>
 #endif
 
+#if HAVE_SYS_TYPES_H
 #include <sys/types.h>
-
-#if HAVE_SYS_STAT_H
-#include <sys/stat.h>
 #endif
 
 #include <fcntl.h>
@@ -246,7 +243,10 @@ int yaz_daemon(const char *progname,
         close(1);
         close(2);
         open("/dev/null", O_RDWR);
-        dup(0); dup(0);
+        if (dup(0) == -1)
+            return 1;
+        if (dup(0) == -1)
+            return 1;
         close(hand[1]);
     }
 
@@ -270,7 +270,9 @@ int yaz_daemon(const char *progname,
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
  */
+
