@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2008 Index Data
+ * Copyright (C) 1995-2009 Index Data
  * See the file LICENSE for details.
  */
 /**
@@ -34,11 +34,8 @@ Z_InitRequest *zget_InitRequest(ODR o)
     r->implementationId = "81";
     r->implementationName = "YAZ";
     r->implementationVersion = YAZ_VERSION
-#ifdef YAZ_DATE_STR
-    " (" YAZ_DATE_STR ")"
-#endif
-#ifdef YAZ_OS
-    " " YAZ_OS
+#ifdef YAZ_VERSION_SHA1
+    " " YAZ_VERSION_SHA1
 #endif
         ;
     r->userInformationField = 0;
@@ -61,11 +58,8 @@ Z_InitResponse *zget_InitResponse(ODR o)
     r->implementationId = "81";
     r->implementationName = "YAZ";
     r->implementationVersion = YAZ_VERSION
-#ifdef YAZ_DATE_STR
-    " (" YAZ_DATE_STR ")"
-#endif
-#ifdef YAZ_OS
-    " " YAZ_OS
+#ifdef YAZ_VERSION_SHA1
+    " " YAZ_VERSION_SHA1
 #endif
         ;
     r->userInformationField = 0;
@@ -652,6 +646,7 @@ Z_External *zget_init_diagnostics_octet(ODR odr, int error,
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
